@@ -195,7 +195,12 @@ def generate_html_string(best_items, names_to_amz_link):
             return_string += f"<li>Retailer: {item[0]}, Price: {item[1]}\n<a href={item[2]}>Website</a>\nTitle: {item[3]}</li>"
         return_string+="</ol>\n\n"
     return return_string
-    
+
+def sort_best_items(row):
+    target_name = row[0]
+    best_match = row[2][0][3]
+    return 1-difflib.SequenceMatcher(None, target_name, best_match).ratio()
+
 @debug_basic(value=True)
 def user_function():
     sg.popup("Please download the html code and THEN click ok", keep_on_top=True)
@@ -222,6 +227,8 @@ def user_function():
 
     best_items=target_items(filtered_results, names_prices_filtered)
 
+    best_items.sort(key=sort_best_items)
+
     import webbrowser
 
 
